summaryrefslogtreecommitdiff
path: root/src/pathfinder/npf/queue.h
diff options
context:
space:
mode:
authoralberth <alberth@openttd.org>2010-08-29 13:47:15 +0000
committeralberth <alberth@openttd.org>2010-08-29 13:47:15 +0000
commit219ad6e0032efd16afa177e6b6e09c7e7a7b4141 (patch)
tree4644cdec6234c7004b2a9eb8bf7a59542c34121b /src/pathfinder/npf/queue.h
parented723385133413160d56694f17165a216123f958 (diff)
downloadopenttd-219ad6e0032efd16afa177e6b6e09c7e7a7b4141.tar.xz
(svn r20688) -Codechange: Rename Queue struct to BinaryHeap.
Diffstat (limited to 'src/pathfinder/npf/queue.h')
-rw-r--r--src/pathfinder/npf/queue.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/src/pathfinder/npf/queue.h b/src/pathfinder/npf/queue.h
index 2dc075b93..897351ae6 100644
--- a/src/pathfinder/npf/queue.h
+++ b/src/pathfinder/npf/queue.h
@@ -7,7 +7,7 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
/** @file queue.h Simple Queue/Hash implementations. */
#ifndef QUEUE_H
#define QUEUE_H
@@ -24,12 +24,11 @@ struct BinaryHeapNode {
};
-/*
- * Binary Heap
- * For information, see:
- * http://www.policyalmanac.org/games/binaryHeaps.htm
+/**
+ * Binary Heap.
+ * For information, see: http://www.policyalmanac.org/games/binaryHeaps.htm
*/
-struct Queue {
+struct BinaryHeap {
static const int BINARY_HEAP_BLOCKSIZE;
static const int BINARY_HEAP_BLOCKSIZE_BITS;
static const int BINARY_HEAP_BLOCKSIZE_MASK;
@@ -7,7 +7,7 @@
* See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with OpenTTD. If not, see <http://www.gnu.org/licenses/>.
*/
-/** @file queue.h Simple Queue/Hash implementations. */
+/** @file queue.h Binary heap implementation, hash implementation. */
#ifndef QUEUE_H
#define QUEUE_H